@@ -43,7 +43,7 @@ class AlgebraicMixin:
     # Derived compound functions
     ##########################################################################
 
-    def _add_derived_compound(self, compound):
+    def _add_derived_compound(self, *, compound):
         """Add a derived compound to the model.
 
         Derived compounds are dynamic quantities calculated by algebraic modules.
@@ -62,7 +62,7 @@ class AlgebraicMixin:
             warnings.warn(f"Overwriting derived compound {compound}")
         self.derived_compounds.append(compound)
 
-    def _add_derived_compounds(self, compounds):
+    def _add_derived_compounds(self, *, compounds):
         """Add multiple derived compounds to the model.
 
         Derived compounds are dynamic quantities calculated by algebraic modules.
@@ -79,7 +79,7 @@ class AlgebraicMixin:
         for compound in compounds:
             self._add_derived_compound(compound=compound)
 
-    def _remove_derived_compound(self, compound):
+    def _remove_derived_compound(self, *, compound):
         """Remove a derived compound from the model.
 
         Parameters
@@ -89,7 +89,7 @@ class AlgebraicMixin:
         """
         self.derived_compounds.remove(compound)
 
-    def _remove_derived_compounds(self, compounds):
+    def _remove_derived_compounds(self, *, compounds):
         """Remove multiple derived compounds from the model.
 
         Parameters
@@ -375,7 +375,7 @@ class AlgebraicMixin:
     # Simulation functions
     ##########################################################################
 
-    def _get_fcd(self, t, y):
+    def _get_fcd(self, *, t, y):
         """Calculate the derived variables of all algebraic modules.
 
         Parameters
@@ -404,7 +404,7 @@ class AlgebraicMixin:
     # Source code functions
     ##########################################################################
 
-    def _generate_algebraic_modules_source_code(self, include_meta_info=True):
+    def _generate_algebraic_modules_source_code(self, *, include_meta_info=True):
         """Generate modelbase source code for algebraic modules.
 
         This is mainly used for the generate_model_source_code function.
@@ -425,8 +425,6 @@ class AlgebraicMixin:
         --------
         generate_model_source_code
         """
-        if include_meta_info:
-            meta_info = self._get_nonzero_meta_info(component="modules")
         module_functions = set()
         modules = []
         for name, module in self.algebraic_modules.items():
@@ -450,6 +448,7 @@ class AlgebraicMixin:
                 f"    parameters={parameters},\n"
             )
             if include_meta_info:
+                meta_info = self._get_nonzero_meta_info(component="modules")
                 try:
                     info = meta_info[name]
                     module_definition += f"**{info}"
@@ -463,7 +462,7 @@ class AlgebraicMixin:
     # SBML functions
     ##########################################################################
 
-    def _create_sbml_algebraic_modules(self, sbml_model):
+    def _create_sbml_algebraic_modules(self, *, sbml_model):
         """Convert the algebraic modules their sbml equivalent.
 
         Notes
