@@ -16,10 +16,12 @@ class Compound:
 
     common_name: str = None
     compartment: str = "c"
+    unit: str = None
     formula: str = None
     charge: float = None
     gibbs0: float = None
     smiles: str = None
+    unit: str = None
     database_links: dict = field(default_factory=dict)
     notes: dict = field(default_factory=dict)
 
@@ -136,7 +138,7 @@ class CompoundMixin:
     # Source code functions
     ##########################################################################
 
-    def _generate_compounds_source_code(self, include_meta_info=True):
+    def _generate_compounds_source_code(self, *, include_meta_info=True):
         """Generate modelbase source code for compounds.
 
         This is mainly used for the generate_model_source_code function.
@@ -161,7 +163,7 @@ class CompoundMixin:
     # SBML functions
     ##########################################################################
 
-    def _create_sbml_compounds(self, sbml_model):
+    def _create_sbml_compounds(self, *, sbml_model):
         """Create the compounds for the sbml model.
 
         Parameters
