@@ -24,25 +24,41 @@ class Rate:
     """Meta-info container for rates."""
 
     common_name: str = None
+    unit: str = None
     gibbs0: float = None
     ec: str = None
+    unit: str = None
     database_links: dict = field(default_factory=dict)
     notes: dict = field(default_factory=dict)
     sbml_function: str = None
+    python_function: str = None
 
 
 class RateMixin:
     """Mixin adding rate functions."""
 
-    def __init__(self, rates=None):
+    def __init__(self, rates=None, functions=None):
         self.rates = {}
+        self.functions = {}
         if rates is not None:
             self.add_rates(rates=rates)
+        if functions is not None:
+            self.add_functions(functions=functions)
 
     ##########################################################################
     # Basic rate functions
     ##########################################################################
 
+    def add_function(self, function_name, function):
+        if function.__name__ == "<lambda>":
+            patch_lambda_function_name(function=function, name=function_name)
+
+        self.functions[function_name] = function
+
+    def add_functions(self, functions):
+        for function_name, function in functions.items():
+            self.add_function(function_name=function_name, function=function)
+
     def add_rate(
         self,
         rate_name,
@@ -122,7 +138,8 @@ class RateMixin:
             else:
                 dynamic_variables = substrates + modifiers
 
-        patch_lambda_function_name(function=function, name=rate_name)
+        if function.__name__ == "<lambda>":
+            patch_lambda_function_name(function=function, name=rate_name)
 
         if rate_name in self.rates:
             warnings.warn(f"Overwriting rate {rate_name}")
@@ -351,14 +368,15 @@ class RateMixin:
         arguments : list(str)
         """
         return list(
-            self.get_rate_dynamic_variables(rate_name=rate_name) + self.get_rate_parameters(rate_name=rate_name)
+            self.get_rate_dynamic_variables(rate_name=rate_name)
+            + self.get_rate_parameters(rate_name=rate_name)
         )
 
     ##########################################################################
     # Simulation functions
     ##########################################################################
 
-    def _get_fluxes(self, y):
+    def _get_fluxes(self, *, y):
         """Calculate the fluxes.
 
         This is the performance optimized version of the function
@@ -388,7 +406,16 @@ class RateMixin:
     # Source code functions
     ##########################################################################
 
-    def _generate_rates_source_code(self, include_meta_info=True):
+    def _generate_function_source_code(self):
+        function_strings = []
+        for name, function in self.functions.items():
+            function_code = get_formatted_function_source_code(
+                function_name=name, function=function, function_type="rate"
+            )
+            function_strings.append(function_code)
+        return "\n".join(sorted(function_strings))
+
+    def _generate_rates_source_code(self, *, include_meta_info=True):
         """Generate modelbase source code for rates.
 
         This is mainly used for the generate_model_source_code function.
@@ -412,9 +439,6 @@ class RateMixin:
         rate_functions = set()
         rates = []
 
-        if include_meta_info:
-            meta_info = self._get_nonzero_meta_info(component="rates")
-
         for name, rate in self.rates.items():
             function = rate["function"]
             substrates = rate["substrates"]
@@ -438,6 +462,7 @@ class RateMixin:
                 f"    reversible={reversible},\n"
             )
             if include_meta_info:
+                meta_info = self._get_nonzero_meta_info(component="rates")
                 try:
                     info = meta_info[name]
                     rate_definition += f"    **{info}\n"
@@ -451,7 +476,7 @@ class RateMixin:
     # SBML functions
     ##########################################################################
 
-    def _create_sbml_rates(self, sbml_model):
+    def _create_sbml_rates(self, *, sbml_model):
         """Convert the rates into sbml reactions.
 
         Parameters
