@@ -1,10 +1,10 @@
 """Write me."""
 
+# Standard Library
 import inspect as inspect
 import re as re
 import subprocess
 
-
 RE_LAMBDA_RATE_FUNC = re.compile(r".*(lambda)(.+?):(.*?),")
 RE_LAMBDA_ALGEBRAIC_MODULE_FUNC = re.compile(r".*(lambda)(.+?):(.*[\(\[].+[\)\]]),")
 RE_TO_SBML = re.compile(r"([^0-9_a-zA-Z])")
@@ -74,13 +74,9 @@ def get_formatted_function_source_code(function_name, function, function_type):
 
     if "lambda" in source:
         if function_type == "rate":
-            source = functionify_rate_function_lambda(
-                lambda_function_code=source, function_name=function_name
-            )
+            source = functionify_rate_function_lambda(lambda_function_code=source, function_name=function_name)
         elif function_type == "module":
-            source = functionify_algebraic_module_lambda(
-                lambda_function_code=source, function_name=function_name
-            )
+            source = functionify_algebraic_module_lambda(lambda_function_code=source, function_name=function_name)
         else:
             raise ValueError("Can only handle rate or module functions")
     blacked_string = subprocess.run(["black", "-c", source], stdout=subprocess.PIPE)
@@ -99,9 +95,7 @@ def functionify_rate_function_lambda(lambda_function_code, function_name):
     -------
     source_code : str
     """
-    _, args, code = re.match(
-        pattern=RE_LAMBDA_RATE_FUNC, string=lambda_function_code
-    ).groups()
+    _, args, code = re.match(pattern=RE_LAMBDA_RATE_FUNC, string=lambda_function_code).groups()
     return f"def {function_name}({args.strip()}):\n    return {code.strip()}"
 
 
@@ -117,9 +111,7 @@ def functionify_algebraic_module_lambda(lambda_function_code, function_name):
     -------
     source_code : str
     """
-    _, args, code = re.match(
-        pattern=RE_LAMBDA_ALGEBRAIC_MODULE_FUNC, string=lambda_function_code
-    ).groups()
+    _, args, code = re.match(pattern=RE_LAMBDA_ALGEBRAIC_MODULE_FUNC, string=lambda_function_code).groups()
     return f"def {function_name}({args.strip()}):\n    return {code.strip()}"
 
 
