@@ -1,15 +1,11 @@
-from .models.model import Model
+# Local code
 from .models.labelmodel import LabelModel
 from .models.linearlabelmodel import LinearLabelModel
-
-from .simulators.simulator import _Simulate
+from .models.model import Model
 from .simulators.labelsimulator import _LabelSimulate
 from .simulators.linearlabelsimulator import _LinearLabelSimulate
-
-from .utils import mca
-from .utils import ratelaws
-from .utils import ratefunctions
-from .utils import algebraicfunctions
+from .simulators.simulator import _Simulate
+from .utils import algebraicfunctions, mca, ratefunctions, ratelaws
 
 
 def Simulator(model, integrator_name="assimulo", **kwargs):
@@ -29,15 +25,11 @@ def Simulator(model, integrator_name="assimulo", **kwargs):
         A simulate object according to the model type
     """
     if integrator_name not in ("assimulo", "scipy"):
-        raise NotImplementedError(
-            "Currently only {assimulo, scipy} are supported as integrators"
-        )
+        raise NotImplementedError("Currently only {assimulo, scipy} are supported as integrators")
     if isinstance(model, LabelModel):
         return _LabelSimulate(model=model, integrator_name=integrator_name, **kwargs)
     elif isinstance(model, LinearLabelModel):
-        return _LinearLabelSimulate(
-            model=model, integrator_name=integrator_name, **kwargs
-        )
+        return _LinearLabelSimulate(model=model, integrator_name=integrator_name, **kwargs)
     elif isinstance(model, Model):
         return _Simulate(model=model, integrator_name=integrator_name, **kwargs)
     else:
