@@ -317,6 +317,8 @@ class Model(
             t = [t]
         return pd.DataFrame(data=self.get_fluxes_dict(y=y, t=t), index=t, columns=self.get_rate_names())
 
+    # This can't get keyword-only arguments, as the integrators are calling it with
+    # positional arguments
     def _get_rhs(self, t, y):
         """Calculate the right hand side of the ODE system.
 
@@ -488,7 +490,9 @@ class Model(
                     )
                 lm.add_reaction(
                     rate_name=rate_name,
-                    stoichiometry={k: v for k, v in self.stoichiometries[rate_name].items() if k in labelcompounds},
+                    stoichiometry={
+                        k: v for k, v in self.stoichiometries[rate_name].items() if k in labelcompounds
+                    },
                     labelmap=labelmaps[rate_name],
                 )
             else:
@@ -516,13 +520,19 @@ class Model(
         """
         parameters = self._generate_parameters_source_code(include_meta_info=include_meta_info)
         compounds = self._generate_compounds_source_code(include_meta_info=include_meta_info)
-        module_functions, modules = self._generate_algebraic_modules_source_code(include_meta_info=include_meta_info)
+        functions = self._generate_function_source_code()
+        module_functions, modules = self._generate_algebraic_modules_source_code(
+            include_meta_info=include_meta_info
+        )
         rate_functions, rates = self._generate_rates_source_code(include_meta_info=include_meta_info)
         stoichiometries = self._generate_stoichiometries_source_code()
 
         model_string = "\n".join(
             (
+                "import math",
+                "import numpy as np",
                 "from modelbase.ode import Model, Simulator",
+                functions,
                 module_functions,
                 rate_functions,
                 "m = Model()",
@@ -543,7 +553,7 @@ class Model(
     # SBML functions
     ##########################################################################
 
-    def _create_sbml_reactions(self, sbml_model):
+    def _create_sbml_reactions(self, *, sbml_model):
         """Create the reactions for the sbml model.
 
         Parameters
