@@ -287,7 +287,7 @@ class _LabelSimulate(_Simulate):
             title_kwargs=title_kwargs,
         )
 
-    def _calculate_label_distribution(self, compound, relative):
+    def _calculate_label_distribution(self, *, compound, relative):
         """Calculate the label distribution of a compound.
 
         Parameters
