@@ -42,7 +42,7 @@ class ModelErrorTests(unittest.TestCase):
             reversible=True,
         )
         with self.assertRaises(KeyError):
-            model._get_fluxes({"x": 2})
+            model._get_fluxes(y={"x": 2})
 
 
 class ModelTests(unittest.TestCase):
@@ -577,8 +577,8 @@ class SBMLTests(unittest.TestCase):
         )
 
         doc = model._create_sbml_document()
-        sbml_model = model._create_sbml_model(doc)
-        model._create_sbml_rates(sbml_model)
+        sbml_model = model._create_sbml_model(doc=doc)
+        model._create_sbml_rates(sbml_model=sbml_model)
 
         rxn = sbml_model.getReaction("v1")
         self.assertEqual(rxn.getId(), "v1")
@@ -607,8 +607,8 @@ class SBMLTests(unittest.TestCase):
         )
 
         doc = model._create_sbml_document()
-        sbml_model = model._create_sbml_model(doc)
-        model._create_sbml_rates(sbml_model)
+        sbml_model = model._create_sbml_model(doc=doc)
+        model._create_sbml_rates(sbml_model=sbml_model)
 
         rxn = sbml_model.getReaction("v1")
         self.assertEqual(rxn.getId(), "v1")
