@@ -1,4 +1,7 @@
+# Standard Library
 import unittest
+
+# Third party
 import numpy as np
 from modelbase.ode import Model, Simulator
 from modelbase.ode import ratefunctions as rf
@@ -6,11 +9,11 @@ from modelbase.ode import ratefunctions as rf
 
 def GENERATE_MODEL():
     parameters = {"k_in": 1, "kf": 1, "kr": 1}
-    m = Model(parameters=parameters)
-    m.add_compounds(["a", "b", "c1", "c2", "d1", "d2", "rate_time"])
+    model = Model(parameters=parameters)
+    model.add_compounds(["a", "b", "c1", "c2", "d1", "d2", "rate_time"])
 
     # Vanilla algebraic module
-    m.add_algebraic_module(
+    model.add_algebraic_module(
         module_name="vanilla_module",
         function=lambda a: (a, 2 * a),
         compounds=["a"],
@@ -20,7 +23,7 @@ def GENERATE_MODEL():
     )
 
     # Time-dependent algebraic module
-    m.add_algebraic_module(
+    model.add_algebraic_module(
         module_name="time_dependent_module",
         function=lambda time: (time,),
         compounds=None,
@@ -30,7 +33,7 @@ def GENERATE_MODEL():
     )
 
     # Singleton reaction
-    m.add_reaction(
+    model.add_reaction(
         rate_name="singleton_reaction",
         function=lambda k_in: k_in,
         stoichiometry={"b": 1},
@@ -40,7 +43,7 @@ def GENERATE_MODEL():
     )
 
     # Time-dependent reaction
-    m.add_reaction(
+    model.add_reaction(
         rate_name="time_dependent_reaction",
         function=lambda time: time,
         stoichiometry={"rate_time": 1},
@@ -49,7 +52,7 @@ def GENERATE_MODEL():
         reversible=False,
     )
     # Vanilla reaction
-    m.add_reaction(
+    model.add_reaction(
         rate_name="vanilla_reaction",
         function=rf.mass_action_1,
         stoichiometry={"c1": -1, "c2": 1},
@@ -58,7 +61,7 @@ def GENERATE_MODEL():
         reversible=False,
     )
     # Reversible reaction
-    m.add_reaction(
+    model.add_reaction(
         rate_name="reversible_reaction",
         function=rf.reversible_mass_action_1_1,
         stoichiometry={"d1": -1, "d2": 1},
@@ -75,11 +78,13 @@ def GENERATE_MODEL():
         "d2": 0,
         "rate_time": 1,
     }
-    return m, y0
+    return model, y0
 
 
 def GENERATE_RESULTS(model, y0):
-    s = Simulator(model,)
+    s = Simulator(
+        model,
+    )
     s.initialise(y0=y0)
     t, y = s.simulate(t_end=10, steps=10)
     return s.copy()
@@ -91,28 +96,28 @@ SIM = GENERATE_RESULTS(model=MODEL, y0=Y0)
 
 class SimulatorBaseTests(unittest.TestCase):
     def test_init(self):
-        m = Model()
-        s = Simulator(m)
+        model = Model()
+        s = Simulator(model=model)
         self.assertEqual(s.time, None)
         self.assertEqual(s.results, None)
         self.assertEqual(s.full_results, None)
 
     def test_update_parameters(self):
-        m = Model(parameters={"k1": 1})
-        s = Simulator(m)
+        model = Model(parameters={"k1": 1})
+        s = Simulator(model=model)
         s.update_parameters(parameters={"k1": 2})
         self.assertEqual(s.model.parameters["k1"], 2)
 
     def test_copy(self):
-        m = Model(parameters={"k_in": 1})
-        m.add_compound(compound="x")
-        m.add_reaction(
+        model = Model(parameters={"k_in": 1})
+        model.add_compound(compound="x")
+        model.add_reaction(
             rate_name="v1",
             function=rf.constant,
             stoichiometry={"x": 1},
             parameters=["k_in"],
         )
-        s1 = Simulator(m)
+        s1 = Simulator(model=model)
         s1.initialise({"x": 0})
 
         s2 = s1.copy()
@@ -121,15 +126,15 @@ class SimulatorBaseTests(unittest.TestCase):
         self.assertIsNot(s1, s2)
 
     def test_copy_nonempty(self):
-        m = Model(parameters={"k_in": 1})
-        m.add_compound(compound="x")
-        m.add_reaction(
+        model = Model(parameters={"k_in": 1})
+        model.add_compound(compound="x")
+        model.add_reaction(
             rate_name="v1",
             function=rf.constant,
             stoichiometry={"x": 1},
             parameters=["k_in"],
         )
-        s1 = Simulator(m)
+        s1 = Simulator(model=model)
         s1.initialise({"x": 0})
         t, y = s1.simulate(1)
 
@@ -142,14 +147,14 @@ class SimulatorBaseTests(unittest.TestCase):
 class SimulationTests(unittest.TestCase):
     def test_simulate(self):
         parameters = {"alpha": 3}
-        m = Model(parameters=parameters)
-        m.add_derived_parameter(
+        model = Model(parameters=parameters)
+        model.add_derived_parameter(
             parameter_name="beta",
             function=lambda alpha: 3 - alpha,
             parameters=["alpha"],
         )
-        m.add_compound(compound="x")
-        m.add_reaction(
+        model.add_compound(compound="x")
+        model.add_reaction(
             rate_name="v1",
             function=lambda x, alpha: alpha * x,
             stoichiometry={"x": 1},
@@ -158,31 +163,36 @@ class SimulationTests(unittest.TestCase):
             reversible=False,
         )
         y0 = {"x": 1}
-        s = Simulator(model=m,)
+        s = Simulator(
+            model=model,
+        )
         s.update_parameter(parameter_name="alpha", parameter_value=2)
         s.initialise(
-            y0=y0, test_run=False,
+            y0=y0,
+            test_run=False,
         )
         t, y = s.simulate(t_end=10)
         self.assertTrue(np.isclose(y[-1][0], np.exp(10)))
         self.assertEqual(s.full_results, None)
 
     def test_simulate_to_steady_state(self):
-        m = Model(parameters={"kf_base": 3})
-        m.add_derived_parameter(
+        model = Model(parameters={"kf_base": 3})
+        model.add_derived_parameter(
             parameter_name="kf",
             function=lambda kf_base: 3 - kf_base,
             parameters=["kf_base"],
         )
-        m.add_compounds(compounds=["x", "y"])
-        m.add_reaction(
+        model.add_compounds(compounds=["x", "y"])
+        model.add_reaction(
             rate_name="v1",
             function=lambda x, kf: kf * x,
             stoichiometry={"x": -1, "y": 1},
             parameters=["kf"],
         )
         y0 = {"x": 1, "y": 0}
-        s = Simulator(model=m,)
+        s = Simulator(
+            model=model,
+        )
         s.update_parameter(parameter_name="kf_base", parameter_value=2)
         s.initialise(y0=y0, test_run=False)
         t, y = s.simulate_to_steady_state()
@@ -191,9 +201,9 @@ class SimulationTests(unittest.TestCase):
 
     def test_parameter_scan(self):
         parameters = {"kf": 1, "kr": 1}
-        m = Model(parameters=parameters)
-        m.add_compounds(compounds=["x", "y"])
-        m.add_reaction(
+        model = Model(parameters=parameters)
+        model.add_compounds(compounds=["x", "y"])
+        model.add_reaction(
             rate_name="v1",
             function=rf.reversible_mass_action_1_1,
             stoichiometry={"x": -1, "y": 1},
@@ -201,7 +211,9 @@ class SimulationTests(unittest.TestCase):
             reversible=True,
         )
         y0 = {"x": 1, "y": 0}
-        s = Simulator(model=m,)
+        s = Simulator(
+            model=model,
+        )
         s.initialise(y0=y0, test_run=True)
         res = s.parameter_scan(
             parameter_name="kf",
@@ -209,18 +221,14 @@ class SimulationTests(unittest.TestCase):
             tolerance=1e-6,
             multiprocessing=False,
         )
-        np.testing.assert_allclose(
-            res["x"], [0.5, 0.25, 0.2, 0.125, 0.1, 0.0625], rtol=1e-6
-        )
-        np.testing.assert_allclose(
-            res["y"], [0.5, 0.75, 0.8, 0.875, 0.9, 0.9375], rtol=1e-6
-        )
+        np.testing.assert_allclose(res["x"], [0.5, 0.25, 0.2, 0.125, 0.1, 0.0625], rtol=1e-6)
+        np.testing.assert_allclose(res["y"], [0.5, 0.75, 0.8, 0.875, 0.9, 0.9375], rtol=1e-6)
 
     def test_parameter_scan_multiprocessing(self):
         parameters = {"kf": 1, "kr": 1}
-        m = Model(parameters=parameters)
-        m.add_compounds(compounds=["x", "y"])
-        m.add_reaction(
+        model = Model(parameters=parameters)
+        model.add_compounds(compounds=["x", "y"])
+        model.add_reaction(
             rate_name="v1",
             function=rf.reversible_mass_action_1_1,
             stoichiometry={"x": -1, "y": 1},
@@ -228,7 +236,9 @@ class SimulationTests(unittest.TestCase):
             reversible=True,
         )
         y0 = {"x": 1, "y": 0}
-        s = Simulator(model=m,)
+        s = Simulator(
+            model=model,
+        )
         s.initialise(y0=y0, test_run=True)
         res = s.parameter_scan(
             parameter_name="kf",
@@ -237,19 +247,13 @@ class SimulationTests(unittest.TestCase):
             multiprocessing=True,
         )
 
-        np.testing.assert_allclose(
-            res["x"], [0.5, 0.25, 0.2, 0.125, 0.1, 0.0625], rtol=1e-6
-        )
-        np.testing.assert_allclose(
-            res["y"], [0.5, 0.75, 0.8, 0.875, 0.9, 0.9375], rtol=1e-6
-        )
+        np.testing.assert_allclose(res["x"], [0.5, 0.25, 0.2, 0.125, 0.1, 0.0625], rtol=1e-6)
+        np.testing.assert_allclose(res["y"], [0.5, 0.75, 0.8, 0.875, 0.9, 0.9375], rtol=1e-6)
 
     def test_get_full_results_array_shape(self):
         s = SIM.copy()
         self.assertEqual(s.get_full_results_array(concatenated=True).shape, (11, 10))
-        self.assertEqual(
-            s.get_full_results_array(concatenated=False)[0].shape, (11, 10)
-        )
+        self.assertEqual(s.get_full_results_array(concatenated=False)[0].shape, (11, 10))
         self.assertEqual(s.full_results[0].shape, (11, 10))
 
     def test_get_full_results_dict_shape(self):
@@ -304,9 +308,7 @@ class SimulationTests(unittest.TestCase):
     def test_get_variable_shape(self):
         s = SIM.copy()
         self.assertEqual(s.get_variable(variable="a", concatenated=True).shape, (11,))
-        self.assertEqual(
-            s.get_variable(variable="a", concatenated=False)[0].shape, (11,)
-        )
+        self.assertEqual(s.get_variable(variable="a", concatenated=False)[0].shape, (11,))
 
     def test_get_variables_shape(self):
         s = SIM.copy()
@@ -323,23 +325,23 @@ class SimulationTests(unittest.TestCase):
         def rate_func(A):
             return A
 
-        m = Model()
-        m.add_compound("x")
-        m.add_parameter("mod_par", 1)
-        m.add_algebraic_module(
+        model = Model()
+        model.add_compound("x")
+        model.add_parameter("mod_par", 1)
+        model.add_algebraic_module(
             module_name="mod_1",
             function=alg_mod,
             derived_compounds=["A"],
             parameters=["mod_par"],
         )
-        m.add_reaction(
+        model.add_reaction(
             rate_name="rate_1",
             function=rate_func,
             stoichiometry={"x": 1},
             modifiers=["A"],
         )
 
-        s = Simulator(m)
+        s = Simulator(model=model)
         s.initialise({"x": 0})
         t, y = s.simulate(t_end=1, time_points=[1])
         s.update_parameter("mod_par", 0.5)
@@ -351,9 +353,7 @@ class SimulationTests(unittest.TestCase):
         np.testing.assert_array_almost_equal(t[0], [0.0, 1.0])
         np.testing.assert_array_almost_equal(t[1], [2.0])
         #
-        np.testing.assert_array_almost_equal(
-            s.get_results_array(concatenated=True), [[0.0], [1.0], [1.5]]
-        )
+        np.testing.assert_array_almost_equal(s.get_results_array(concatenated=True), [[0.0], [1.0], [1.5]])
         #
         r = s.get_results_array(concatenated=False)
         np.testing.assert_array_almost_equal(r[0], [[0.0], [1.0]])
@@ -368,9 +368,7 @@ class SimulationTests(unittest.TestCase):
         self.assertEqual(list(df.index), [0.0, 1.0, 2.0])
         np.testing.assert_array_almost_equal(df.values, [[0.0], [1.0], [1.5]])
         #
-        np.testing.assert_array_almost_equal(
-            s.get_full_results_array(), np.array([[0.0, 1.0], [1.0, 1.0], [1.5, 0.5]])
-        )
+        np.testing.assert_array_almost_equal(s.get_full_results_array(), np.array([[0.0, 1.0], [1.0, 1.0], [1.5, 0.5]]))
         #
         d = s.get_full_results_dict()
         self.assertEqual(list(d.keys()), ["x", "A"])
@@ -380,13 +378,9 @@ class SimulationTests(unittest.TestCase):
         df = s.get_full_results_df()
         self.assertEqual(list(df.keys()), ["x", "A"])
         self.assertEqual(list(df.index), [0.0, 1.0, 2.0])
-        np.testing.assert_array_almost_equal(
-            df.values, [[0.0, 1.0], [1.0, 1.0], [1.5, 0.5]]
-        )
+        np.testing.assert_array_almost_equal(df.values, [[0.0, 1.0], [1.0, 1.0], [1.5, 0.5]])
         #
-        np.testing.assert_array_almost_equal(
-            s.get_fluxes_array(), [[1.0], [1.0], [0.5]]
-        )
+        np.testing.assert_array_almost_equal(s.get_fluxes_array(), [[1.0], [1.0], [0.5]])
         #
         d = s.get_fluxes_dict()
         self.assertEqual(list(d.keys()), ["rate_1"])
@@ -399,9 +393,9 @@ class SimulationTests(unittest.TestCase):
 
     def test_normalise_results(self):
         parameters = {"alpha": 1}
-        m = Model(parameters=parameters)
-        m.add_compound(compound="x")
-        m.add_reaction(
+        model = Model(parameters=parameters)
+        model.add_compound(compound="x")
+        model.add_reaction(
             rate_name="v1",
             function=lambda x, alpha: alpha * x,
             stoichiometry={"x": 1},
@@ -410,7 +404,7 @@ class SimulationTests(unittest.TestCase):
             reversible=False,
         )
         y0 = {"x": 1}
-        s = Simulator(model=m)
+        s = Simulator(model=model)
         s.initialise(y0=y0, test_run=False)
         t, y = s.simulate(t_end=10)
 
@@ -419,48 +413,26 @@ class SimulationTests(unittest.TestCase):
 
         # array
         np.testing.assert_array_equal(y / 2, s.get_results_array(normalise=2))
-        np.testing.assert_array_equal(
-            y / 2, s.get_results_array(normalise=np.ones(len(y)) * 2)
-        )
-        np.testing.assert_array_equal(
-            y / 2, s.get_results_array(normalise=[np.ones(len(y)) * 2])
-        )
+        np.testing.assert_array_equal(y / 2, s.get_results_array(normalise=np.ones(len(y)) * 2))
+        np.testing.assert_array_equal(y / 2, s.get_results_array(normalise=[np.ones(len(y)) * 2]))
 
         # full array
         np.testing.assert_array_equal(y / 2, s.get_full_results_array(normalise=2))
-        np.testing.assert_array_equal(
-            y / 2, s.get_full_results_array(normalise=np.ones(len(y)) * 2)
-        )
-        np.testing.assert_array_equal(
-            y / 2, s.get_full_results_array(normalise=[np.ones(len(y)) * 2])
-        )
+        np.testing.assert_array_equal(y / 2, s.get_full_results_array(normalise=np.ones(len(y)) * 2))
+        np.testing.assert_array_equal(y / 2, s.get_full_results_array(normalise=[np.ones(len(y)) * 2]))
 
         # dict
-        np.testing.assert_array_equal(
-            (y / 2).flatten(), s.get_results_dict(normalise=2)["x"]
-        )
-        np.testing.assert_array_equal(
-            (y / 2).flatten(), s.get_results_dict(normalise=np.ones(len(y)) * 2)["x"]
-        )
-        np.testing.assert_array_equal(
-            (y / 2).flatten(), s.get_results_dict(normalise=[np.ones(len(y)) * 2])["x"]
-        )
+        np.testing.assert_array_equal((y / 2).flatten(), s.get_results_dict(normalise=2)["x"])
+        np.testing.assert_array_equal((y / 2).flatten(), s.get_results_dict(normalise=np.ones(len(y)) * 2)["x"])
+        np.testing.assert_array_equal((y / 2).flatten(), s.get_results_dict(normalise=[np.ones(len(y)) * 2])["x"])
 
         # dict
-        np.testing.assert_array_equal(
-            (y / 2).flatten(), s.get_results_dict(normalise=2)["x"]
-        )
-        np.testing.assert_array_equal(
-            (y / 2).flatten(), s.get_results_dict(normalise=np.ones(len(y)) * 2)["x"]
-        )
-        np.testing.assert_array_equal(
-            (y / 2).flatten(), s.get_results_dict(normalise=[np.ones(len(y)) * 2])["x"]
-        )
+        np.testing.assert_array_equal((y / 2).flatten(), s.get_results_dict(normalise=2)["x"])
+        np.testing.assert_array_equal((y / 2).flatten(), s.get_results_dict(normalise=np.ones(len(y)) * 2)["x"])
+        np.testing.assert_array_equal((y / 2).flatten(), s.get_results_dict(normalise=[np.ones(len(y)) * 2])["x"])
 
         # full dict
-        np.testing.assert_array_equal(
-            (y / 2).flatten(), s.get_full_results_dict(normalise=2)["x"]
-        )
+        np.testing.assert_array_equal((y / 2).flatten(), s.get_full_results_dict(normalise=2)["x"])
         np.testing.assert_array_equal(
             (y / 2).flatten(),
             s.get_full_results_dict(normalise=np.ones(len(y)) * 2)["x"],
@@ -471,32 +443,20 @@ class SimulationTests(unittest.TestCase):
         )
 
         # df
-        np.testing.assert_array_equal(
-            (y / 2).flatten(), s.get_results_df(normalise=2)["x"]
-        )
-        np.testing.assert_array_equal(
-            (y / 2).flatten(), s.get_results_df(normalise=np.ones(len(y)) * 2)["x"]
-        )
-        np.testing.assert_array_equal(
-            (y / 2).flatten(), s.get_results_df(normalise=[np.ones(len(y)) * 2])["x"]
-        )
+        np.testing.assert_array_equal((y / 2).flatten(), s.get_results_df(normalise=2)["x"])
+        np.testing.assert_array_equal((y / 2).flatten(), s.get_results_df(normalise=np.ones(len(y)) * 2)["x"])
+        np.testing.assert_array_equal((y / 2).flatten(), s.get_results_df(normalise=[np.ones(len(y)) * 2])["x"])
 
         # full df
-        np.testing.assert_array_equal(
-            (y / 2).flatten(), s.get_full_results_df(normalise=2)["x"]
-        )
-        np.testing.assert_array_equal(
-            (y / 2).flatten(), s.get_full_results_df(normalise=np.ones(len(y)) * 2)["x"]
-        )
+        np.testing.assert_array_equal((y / 2).flatten(), s.get_full_results_df(normalise=2)["x"])
+        np.testing.assert_array_equal((y / 2).flatten(), s.get_full_results_df(normalise=np.ones(len(y)) * 2)["x"])
         np.testing.assert_array_equal(
             (y / 2).flatten(),
             s.get_full_results_df(normalise=[np.ones(len(y)) * 2])["x"],
         )
 
         # variable
-        np.testing.assert_array_equal(
-            (y / 2).flatten(), s.get_variable(variable="x", normalise=2)
-        )
+        np.testing.assert_array_equal((y / 2).flatten(), s.get_variable(variable="x", normalise=2))
         np.testing.assert_array_equal(
             (y / 2).flatten(),
             s.get_variable(variable="x", normalise=np.ones(len(y)) * 2),
@@ -507,43 +467,21 @@ class SimulationTests(unittest.TestCase):
         )
 
         # variables
-        np.testing.assert_array_equal(
-            y / 2, s.get_variables(variables=["x"], normalise=2)
-        )
-        np.testing.assert_array_equal(
-            y / 2, s.get_variables(variables=["x"], normalise=np.ones(len(y)) * 2)
-        )
-        np.testing.assert_array_equal(
-            y / 2, s.get_variables(variables=["x"], normalise=[np.ones(len(y)) * 2])
-        )
+        np.testing.assert_array_equal(y / 2, s.get_variables(variables=["x"], normalise=2))
+        np.testing.assert_array_equal(y / 2, s.get_variables(variables=["x"], normalise=np.ones(len(y)) * 2))
+        np.testing.assert_array_equal(y / 2, s.get_variables(variables=["x"], normalise=[np.ones(len(y)) * 2]))
 
         # fluxes array
         np.testing.assert_array_equal(y / 2, s.get_fluxes_array(normalise=2))
-        np.testing.assert_array_equal(
-            y / 2, s.get_fluxes_array(normalise=np.ones(len(y)) * 2)
-        )
-        np.testing.assert_array_equal(
-            y / 2, s.get_fluxes_array(normalise=[np.ones(len(y)) * 2])
-        )
+        np.testing.assert_array_equal(y / 2, s.get_fluxes_array(normalise=np.ones(len(y)) * 2))
+        np.testing.assert_array_equal(y / 2, s.get_fluxes_array(normalise=[np.ones(len(y)) * 2]))
 
         # fluxes dict
-        np.testing.assert_array_equal(
-            (y / 2).flatten(), s.get_fluxes_dict(normalise=2)["v1"]
-        )
-        np.testing.assert_array_equal(
-            (y / 2).flatten(), s.get_fluxes_dict(normalise=np.ones(len(y)) * 2)["v1"]
-        )
-        np.testing.assert_array_equal(
-            (y / 2).flatten(), s.get_fluxes_dict(normalise=[np.ones(len(y)) * 2])["v1"]
-        )
+        np.testing.assert_array_equal((y / 2).flatten(), s.get_fluxes_dict(normalise=2)["v1"])
+        np.testing.assert_array_equal((y / 2).flatten(), s.get_fluxes_dict(normalise=np.ones(len(y)) * 2)["v1"])
+        np.testing.assert_array_equal((y / 2).flatten(), s.get_fluxes_dict(normalise=[np.ones(len(y)) * 2])["v1"])
 
         # fluxes df
-        np.testing.assert_array_equal(
-            (y / 2).flatten(), s.get_fluxes_df(normalise=2)["v1"]
-        )
-        np.testing.assert_array_equal(
-            (y / 2).flatten(), s.get_fluxes_df(normalise=np.ones(len(y)) * 2)["v1"]
-        )
-        np.testing.assert_array_equal(
-            (y / 2).flatten(), s.get_fluxes_df(normalise=[np.ones(len(y)) * 2])["v1"]
-        )
+        np.testing.assert_array_equal((y / 2).flatten(), s.get_fluxes_df(normalise=2)["v1"])
+        np.testing.assert_array_equal((y / 2).flatten(), s.get_fluxes_df(normalise=np.ones(len(y)) * 2)["v1"])
+        np.testing.assert_array_equal((y / 2).flatten(), s.get_fluxes_df(normalise=[np.ones(len(y)) * 2])["v1"])
