@@ -90,7 +90,7 @@ class MCATests(unittest.TestCase):
         )
 
 
-class MCALinarChainTests(unittest.TestCase):
+class MCALinearChainTests(unittest.TestCase):
     def create_model(self):
         parameters = {
             "k_in": 1,
